/* Copyright (c) 1999 Christopher Y. Wong
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import java.util.*;
import java.awt.*;
import java.awt.event.*;

public class BookmarkCtrl implements ActionListener
{
  public BookmarkCtrl(Frame parent, DocReaderModel docReaderModel)
  {
    this.parent = parent;
    this.docReaderModel = docReaderModel;
  }

  public void go()
  {
    if (!docReaderModel.isValid()) {
      Toolkit.getDefaultToolkit().beep();
      return;
    }
    view = new BookmarkView(parent, this);
    model = docReaderModel.getBookmarks();
    model.addObserver(view);
    model.update();
    view.show();
  }

  public void actionPerformed(ActionEvent e)
  {
    Object source = e.getSource();

    if (source == view.cancelButton) {
      view.setVisible(false);
      view.dispose();
    } else if (source == view.addButton)
      doAddBookmark();
    else if (source == view.delButton)
      model.deleteBookmark(view.listBox.getSelectedIndex());
    else if (source == view.listBox || source == view.goButton)
      goSelectedBookmark();
  }

  private void goSelectedBookmark()
  {
    model.goBookmark(view.listBox.getSelectedIndex());
    view.setVisible(false);
    view.dispose();
  }
  
  private void doAddBookmark()
  {
    String bmkTitle = view.bmkTitle.getText().trim();
    if (bmkTitle.length() > 0) {
      model.addBookmark(bmkTitle);
      view.bmkTitle.setText("");
      view.bmkTitle.requestFocus();
    } else {
      // user has not entered the bookmark name
      Toolkit.getDefaultToolkit().beep();
    }
  }

  private Frame parent;
  private BookmarkModel model;
  private BookmarkView view;
  private DocReaderModel docReaderModel;
}
