/* Copyright (c) 1999 Christopher Y. Wong
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import java.util.Observer;
import java.util.Observable;
import java.awt.*;

class BookmarkView extends Dialog implements Observer
{
  public BookmarkView(Frame parent, BookmarkCtrl controller)
  {
    super(parent, "Doc Bookmarks", true);
    setLayout(new BorderLayout());

    Panel inputPanel = new Panel(new BorderLayout());
    bmkTitle = new TextField(50);
    inputPanel.add(bmkTitle, BorderLayout.NORTH);
    listBox = new List();
    listBox.addActionListener(controller);
    inputPanel.add(listBox, BorderLayout.CENTER);
    add(inputPanel, BorderLayout.CENTER);

    Panel buttonPanel = new Panel(new GridLayout(4,1));
    addButton = new Button("Add");
    addButton.addActionListener(controller);
    buttonPanel.add(addButton);
    delButton = new Button("Delete");
    delButton.addActionListener(controller);
    buttonPanel.add(delButton);
    goButton = new Button("Go");
    goButton.addActionListener(controller);
    buttonPanel.add(goButton);
    cancelButton = new Button("Cancel");
    cancelButton.addActionListener(controller);
    buttonPanel.add(cancelButton);
    Panel rightPanel = new Panel(new BorderLayout());
    rightPanel.add(buttonPanel, BorderLayout.NORTH);
    add(rightPanel, BorderLayout.EAST);

    // make window taller than minimal
    pack();
    Dimension mysize = getSize();
    mysize.height += 100;
    setSize(mysize);
    
    Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
    setLocation((screenSize.width - mysize.width)/2, 
		(screenSize.height - mysize.height)/2);
  }

  public void update(Observable o, Object arg)
  {
    Bookmark bookmark;
    BookmarkModel model = (BookmarkModel) o;
    listBox.removeAll();
    for (int i=0; (bookmark = model.getBookmark(i)) != null; i++)
      listBox.addItem(bookmark.name);
  }
  
  List listBox;
  TextField bmkTitle;
  Button addButton, delButton, goButton, cancelButton;
}
