/* Copyright (c) 1999 Christopher Y. Wong
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import java.util.*;
import java.io.*;
import java.awt.*;
import java.awt.event.*;

public class DocReaderCtrl implements ActionListener,
  ComponentListener, KeyListener, AdjustmentListener
{
  public DocReaderCtrl()
  {
    view = new DocReaderView(this);
    model = new DocReaderModel(view.getViewBounds());
    model.addObserver(view);
    searcher = new Searcher(view, model);
    bookmarker = new BookmarkCtrl(view, model);

    fileDialog = new FileDialog(view);
    fileDialog.setMode(FileDialog.LOAD);
    fileDialog.setTitle("Open Doc file");
  }

   public void run(String path)
   {
      view.setVisible(true);
      if (path != null)
	 model.open(path);
   }
  
  public void actionPerformed(ActionEvent e)
  {
    Object source = e.getSource();

    if (source == view.openButton) 
      openFile();
    else if (source == view.searchButton)
      searcher.go();
    else if (source == view.bmkButton)
      bookmarker.go();
    else if (source == view.topButton)
      model.goTop();
    else if (source == view.bottomButton)
      model.goBottom();
    else if (source == view.quitButton) {
      BookmarkModel bookmarks = model.getBookmarks();
      if (bookmarks != null)
	bookmarks.save();
      System.exit(0);
    }
  }

  private void openFile()
  {
    fileDialog.setFile("*.p??");
    fileDialog.show();
    if (fileDialog.getFile() != null)
      model.open(fileDialog.getDirectory() + fileDialog.getFile());
  }

  public void componentResized(ComponentEvent e)
  {
    view.adjustBounds();
    model.loadPage();
  }

   public void keyPressed(KeyEvent e)
   {
      switch (e.getKeyCode()) {
      case KeyEvent.VK_DOWN: 
	model.lineDown(); 
	e.consume();
	break;
      case KeyEvent.VK_PAGE_DOWN: 
	model.pageDown();
	e.consume();
	break;
      case KeyEvent.VK_UP: 
	model.lineUp(); 
	e.consume();
	break;
      case KeyEvent.VK_PAGE_UP: 
	model.pageUp(); 
	e.consume();
	break;
      case KeyEvent.VK_HOME:
	model.goTop();
	e.consume();
	break;
      case KeyEvent.VK_END:
	model.goBottom();
	e.consume();
	break;
      }
   }

   public void adjustmentValueChanged(AdjustmentEvent e)
   {
      if (!model.isValid()) return;
      
      switch (e.getAdjustmentType()) {
      case AdjustmentEvent.UNIT_INCREMENT:
	 model.lineDown();
	 break;
      case AdjustmentEvent.UNIT_DECREMENT:
	 model.lineUp();
	 break;
      case AdjustmentEvent.BLOCK_INCREMENT:
	 model.pageDown();
	 break;
      case AdjustmentEvent.BLOCK_DECREMENT:
	 model.pageUp();
	 break;
      case AdjustmentEvent.TRACK:
	 int newLoc = e.getValue();
	 if (0 <= newLoc && newLoc <= model.getEndLoc())
	    model.setCurrentLoc(newLoc);
      default:
      }
   }

   public void keyReleased(KeyEvent e) {}
   public void keyTyped(KeyEvent e) {}
   
  public void componentMoved(ComponentEvent e) {}
  public void componentShown(ComponentEvent e) {}
  public void componentHidden(ComponentEvent e) {}
  
  DocReaderView view;
  DocReaderModel model;
  FileDialog fileDialog;
  Searcher searcher;
  BookmarkCtrl bookmarker;
}

