/* Copyright (c) 1999 Christopher Y. Wong
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import java.awt.*;
import java.util.*;

public class DocReaderView extends Frame implements Observer
{
  public DocReaderView(DocReaderCtrl controller)
  {
    setLayout(new BorderLayout());

    // create buttons panel
    Panel buttonPanel = new Panel(new GridLayout(1, 6));
    //buttonPanel.setFont(new Font("SansSerif",Font.PLAIN,10));
    openButton = createAddButton("Open", controller, buttonPanel);
    searchButton = createAddButton("Search", controller, buttonPanel);
    bmkButton = createAddButton("Bookmarks", controller, buttonPanel);
    topButton = createAddButton("Top", controller, buttonPanel);
    bottomButton = createAddButton("Bottom", controller, buttonPanel);
    quitButton = createAddButton("Quit", controller, buttonPanel);
    add(buttonPanel, BorderLayout.NORTH);

    // create main text area
    textArea = new TextWidget();
    textArea.addKeyListener(controller);
    add(textArea, BorderLayout.CENTER);

    // status line
    statusLine = new Label(" Written by Christopher Y. Wong, ported by Ramon Wartala");
    add(statusLine, BorderLayout.SOUTH);

    // scrollbar
    scrollbar = new Scrollbar(Scrollbar.VERTICAL);
    scrollbar.addAdjustmentListener(controller);
    add(scrollbar, BorderLayout.EAST);

    //Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
    setTitle("Doc Reader for Nokia9210");
    setSize(640, 200);
    //setLocation((screenSize.width - 450)/2, (screenSize.height - 500)/2);
    setLocation(0,0);
    addComponentListener(controller);

    viewBounds = new ViewBounds(textArea);
  }

   // do not clear window. This update() is copied from Container.java in jdk
   // 1.1.5, with the call to super.update() replaced with paint(g). This is
   // necessary to prevent flickering in TextWidget, a lightweight component.
   public final void update(Graphics g)
   {
      if (isShowing()) {
	 paint(g);
	 int ncomponents = getComponentCount();
	 Component component[] = getComponents();
	 Rectangle clip = g.getClipBounds();
	 for (int i = ncomponents - 1 ; i >= 0 ; i--) {
	    Component comp = component[i];
	    if (comp != null &&
		comp instanceof TextWidget && comp.isVisible()) {

	       Rectangle cr = comp.getBounds();
	       if ((clip == null) || cr.intersects(clip)) {
		  Graphics cg = g.create(cr.x, cr.y, cr.width, cr.height);
		  try {
		     comp.update(cg);
		  } finally {
		     cg.dispose();
		  }
	       }
	    }
	 }
      }
   }

  public ViewBounds getViewBounds() { return viewBounds; }

  public void setVisible(boolean state)
  {
    super.setVisible(state);
    adjustBounds();
  }

  public void update(Observable o, Object arg)
  {
    DocReaderModel model = (DocReaderModel) o;
    statusLine.setText(model.getMessage());
    openButton.requestFocus();
    String text = model.getText();
    textArea.setText(text);
    scrollbar.setValues(model.getCurrentLoc(), text.length(), 0,
			model.getEndLoc());
  }

  public void adjustBounds()
  {
    viewBounds.setBounds(textArea, false);
  }

   private Button createAddButton(String label, DocReaderCtrl controller,
				  Panel buttonPanel)
   {
      Button button = new Button(label);
      button.addActionListener(controller);
      button.addKeyListener(controller);
      buttonPanel.add(button);
      return button;
   }

   Button searchButton;
   Button openButton, bmkButton, topButton, bottomButton, quitButton;
   Scrollbar scrollbar;
   TextWidget textArea;
   StringBuffer buffer;
   Label statusLine;
   ViewBounds viewBounds;
}
