/* Copyright (c) 1999 Christopher Y. Wong
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import java.text.*;
import java.io.*;

class PRCHeader
{
   PRCHeader(DataInput data) throws IOException
   {
      unknown = new int[3];
      time = new int[3];

      // get title
      title = null;
      byte bName[] = new byte[32];
      data.readFully(bName);
      for (int i=0; i<bName.length; i++)
	 if (bName[i] == 0x00) {
	    title = new String(bName, 0, i);
	    break;
	 }
      if (title == null)
	 title = new String(bName, 0, bName.length);

      // get int data
      unknown[0] = data.readInt();
      time[0] = data.readInt();
      time[1] = data.readInt();
      time[2] = data.readInt();
      lastSync = data.readInt();
      ofsSort = data.readInt();
      ofsCategories = data.readInt();
      creator = data.readInt();
      type = data.readInt();
      unknown[1] = data.readInt();
      unknown[2] = data.readInt();
      numRecs = data.readUnsignedShort();

      /*
      System.out.println("PRC header info:");
      System.out.println(" title = " + title);
      System.out.println(" creator = " + creator);
      System.out.println(" type = " + type);
      System.out.println(" numRecs = " + numRecs);
      */
   }

  public String getTitle() { return title; }
  public int getNumRecs() { return numRecs; }
  public boolean isDocFile() 
  { return (creator==DOC_CREATOR) && (type==DOC_TYPE || type==DOC_TYPE2); }
   
  private String title;
  private int unknown[];
  private int time[];
  private int lastSync, ofsSort, ofsCategories;
  private int creator, type;
  private int numRecs;

  private static final int DOC_CREATOR = 1413830772; // = "TEXt" Doc
  private static final int DOC_TYPE = 1380270436; // = "REAd" AportisDoc
  private static final int DOC_TYPE2 = 1416381539; // = "TlDc" TealDoc
}
