/* Copyright (c) 1999 Christopher Y. Wong
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import java.awt.*;
import java.awt.event.*;

class Searcher implements ActionListener
{
  public Searcher(DocReaderView parentWin, DocReaderModel model)
  {
    this.parentWin = parentWin;
    this.model = model;
  }

  public void go()
  {
    view = new SearchView(parentWin, this);
    view.searchFld.setText("");
    view.caseSensitive.setState(false);
    view.againButton.setEnabled(false); 
    view.show();
    view.searchFld.requestFocus();
  }

  public void actionPerformed(ActionEvent e)
  {
    boolean ret; 

    searchText = view.searchFld.getText();
    Object source = e.getSource();
    if ((source == view.searchButton || source == view.searchFld) && 
	searchText.length() > 0) {
      ret = model.doSearch(searchText, !view.caseSensitive.getState());
      if (!ret)
	Toolkit.getDefaultToolkit().beep();
      else 
	view.againButton.setEnabled(true);
    } else if (source == view.againButton && searchText.length() > 0) {
      ret = model.doSearchAgain(searchText, !view.caseSensitive.getState());
      if (!ret)
	Toolkit.getDefaultToolkit().beep();
    } else if (source == view.doneButton)
      view.dispose(); // we get focus problems in Win95 if we only hide it.
  }

  private String searchText;
  private SearchView view;
  private DocReaderModel model;
  private DocReaderView parentWin;
}
