/* Copyright (c) 1999 Christopher Y. Wong
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import java.awt.*;

public class ViewBounds
{
  public ViewBounds(TextWidget textArea)
  { setBounds(textArea, true); }

  public void setBounds(TextWidget textArea, boolean fontChanged)
  {
    if (fontChanged) {
      Font myfont = textArea.getFont();
      this.fm = Toolkit.getDefaultToolkit().getFontMetrics(myfont);
      charWidths = fm.getWidths();
    }

    rows = textArea.getRows();

    hsize = textArea.getBounds().width - 15;

    // estimate number of characters that would fit on a line
    String sample = "The truth will set you free";
    float charWidth = fm.stringWidth(sample)/sample.length();
    estimatedColumns = (int) (hsize / charWidth) - 10;
  }

  final public int getEstimatedColumns() { return estimatedColumns; }
  
  final public int getRows() { return rows; }

  final public int getWidth() { return hsize; }
  
  final public boolean lineFits(StringBuffer line) 
  {
     int width = 0;

     // find width of line by totalling width of its characters
     for (int i=0; i<line.length(); i++) {
	char ch = line.charAt(i);
	if (ch > charWidths.length) 
	   width += charWidths['m']; // default character width
	else
	   width += charWidths[ch];
     }

     return width < hsize;
  }

  int estimatedColumns;
  int charWidths[];
  int rows, hsize;
  FontMetrics fm;
}
