import java.awt.Font;
import java.awt.Color;
import java.awt.Canvas;
import java.awt.Graphics;
import java.awt.Dimension;

public class PieChartCanvas extends Canvas {
  private ChartItem[] wedges;
  private double total;
  private int ncolors;
  private Color wedgeColor[];
  private int pieBorderWidth = 10;
  private Font pieFont;
  private int pieViewSize;
  private int pieDiameter;
  private int pieRadius;
  private int pieCenterPos;
  private boolean drawData;

  public PieChartCanvas() {
    drawData = false;
    wedges = null;
    total = 0.0;
  }

  public void setSize(int asize) {
    pieViewSize = asize;
    pieDiameter = pieViewSize - 2 * pieBorderWidth;
    pieRadius = pieDiameter/2;
    pieCenterPos = pieBorderWidth+pieRadius;
  }

  public void setData(ChartItem[] items) {
    total = 0.0;
    if(items != null) {
      this.wedges = items;
      for (int i = 0; i<wedges.length; i++) {
        total += wedges[i].getFraction();
      }
    }
  }

  public void setFont(Font fnt) {
    this.pieFont = fnt;
  }

  public void setDrawData(boolean drawData) {
    this.drawData = drawData;
  }

  public void setBackgroundColor(Color bgColor) {
    this.setBackground(bgColor);
  }

  public void paint(Graphics g) {
    int startDeg = 0;
    int arcDeg;
    int x, y;
    double angleRad;

    if(drawData) {
      // set shadow color
      g.setColor(Color.lightGray);
      g.fillOval(pieBorderWidth+3,pieBorderWidth+3,pieDiameter,pieDiameter);

      // set the other color
      g.setColor(Color.gray); // "other" is gray
      g.fillOval(pieBorderWidth,pieBorderWidth,pieDiameter,pieDiameter);

      for (int i = 0; i < this.wedges.length; i++) {
        arcDeg = (int)((this.wedges[i].getFraction() / total) * 360);
        int[] rgbColor = this.wedges[i].getRGB();
        Color rgb = new Color(rgbColor[0],rgbColor[1],rgbColor[2]);
        g.setColor(rgb);
        g.fillArc(pieBorderWidth,pieBorderWidth,pieDiameter,pieDiameter,startDeg,arcDeg);
        startDeg += arcDeg;
      } // draw wedges
      startDeg = 0; // Do labels so they go on top of the wedges.
      for (int i = 0; i<this.wedges.length; i++) {
        arcDeg = (int)((this.wedges[i].getFraction() / total) * 360);
        if (arcDeg > 3) { // don't label small wedges
          g.setColor(Color.black);
          angleRad = (float) (startDeg+(arcDeg/2))* java.lang.Math.PI / 180.0;
          x = pieCenterPos + (int)((pieRadius/1.3)*java.lang.Math.cos(angleRad));
          y = pieCenterPos - (int)((pieRadius/1.3)*java.lang.Math.sin(angleRad)) + 5; // 5 is about half the height of the text
          g.drawString(this.wedges[i].getLabel(), x, y);
        } // don't label small wedges
        startDeg += arcDeg;
      } // for
    }
  } // paint()

  public Dimension preferredSize () {
    return new Dimension (pieViewSize,pieViewSize);
  }
}