/**
 * xmlChartParser
 *
 * Simple chart parser, based on a event-centric kXML model
 *
 * @author Ramon Wartala
 * @version 0.5
 */
import java.util.Vector;
import java.util.StringTokenizer;
import java.io.*;
import org.kxml.*;
import org.kxml.parser.*;

public class xmlChartParser {
  private String fileName;
  private InputStream is;
  private static XmlParser parser;
  private String title;

  /**
   * Constructor
   * @params Filename to specified the XML file
   */
  public xmlChartParser(String fileName) {
    this.fileName = fileName;
  }

  /**
   * Get the title of stored XML chart
   */
  public String getTitle() { return this.title; }

  /**
   * Tests the file parameters
   * @throws IOException
   */
  public boolean canOpen() throws IOException {
    File file = new File(this.fileName);
    if(file.canRead()) {
      if(!file.isFile()) {
        return false;
      } else {
        return true;
      }
    } else {
      return false;
    }
  }

  /**
   * Retrieve and parse all chart items from specific XML format.
   *
   * @return Array of ChartItem
   * @throws java.io.IOException
   */
  public ChartItem[] getChartItems() throws IOException {
    Vector items = new Vector();
    ChartItem[] chartItems = null;

    parser =
      new XmlParser(new InputStreamReader(new FileInputStream(this.fileName)));

    int itemIndex = 0;
    String label = null;
    StringTokenizer colorTokenizer = null;
    int[] rgb = null;
    double value = 0.0;

    while (true) {
      parser.skip();
      ParseEvent event = parser.read();

      if(event.getType() == Xml.START_TAG && event.getName().equals("simple_chart")) {
        this.title = new String(event.getAttribute("title").getValue());
      } else if(event.getType() == Xml.START_TAG && event.getName().equals("chart_item")) {
        //System.out.println(parser.readText());
      } else if(event.getType() == Xml.START_TAG && event.getName().equals("label")) {
        label = parser.readText();
      } else if(event.getType() == Xml.START_TAG && event.getName().equals("value")) {
        value = new Double(parser.readText()).doubleValue();
      } else if(event.getType() == Xml.START_TAG && event.getName().equals("color")) {
        colorTokenizer = new StringTokenizer(parser.readText(),",");
        rgb = new int[3];
        for(int i=0;colorTokenizer.hasMoreElements();i++) {
          rgb[i] = Integer.parseInt(colorTokenizer.nextToken());
        }
        colorTokenizer = null;
      } else if(event.getType() == Xml.END_TAG && event.getName().equals("chart_item")) {
        ChartItem item = new ChartItem(label,value,rgb);
        items.addElement(item);
      } else if(event.getType() == Xml.END_DOCUMENT) {
        chartItems = new ChartItem[items.size()];
        items.copyInto(chartItems);
        items = null;
        break;
      }
    }

    parser = null;
    return chartItems;
  }
}